@@ -21,7 +21,9 @@ def update_version(package: str = 'dummy_autoupdate') -> bool:
 
     try:
         logger.info(f'Updating the package with {executable}.')
-        res = subprocess.check_call([executable, "-m", "pip", "install", "--upgrade", package])
+        CREATE_NO_WINDOW = 0x08000000
+        res = subprocess.check_call([executable, "-m", "pip", "install", "--upgrade", package],
+                                    creationflags=CREATE_NO_WINDOW)
         logger.info(f'res = {res}')
         return True
 
